@@ -48,7 +48,7 @@
 #include <float.h>
 #include <math.h>
 #include "lusol.h"
-#include "R_ext/BLAS.h"
+#include "myblas.h"
 #ifdef MATLAB
   #include "mex.h"
 #endif
@@ -63,6 +63,16 @@ void *clean_realloc(void *oldptr, int width, int newsize, int oldsize)
 {
   newsize *= width;
   oldsize *= width;
+/* FIX CRAN warning START
+   The valgrind 'additional issue' checks are now being done with Fedora 38 
+   and its valgrind 3.21.0.  This is flagging 'realloc with size 0' in packages
+*/
+  if (newsize <= 0) {
+    free(oldptr);
+    oldptr = NULL;
+    return(oldptr);
+  }
+/* FIX CRAN warning END*/
   oldptr = LUSOL_REALLOC(oldptr, newsize);
   if(newsize > oldsize)
 /*    MEMCLEAR(oldptr+oldsize, newsize-oldsize); */
@@ -280,7 +290,7 @@ LUSOLrec *LUSOL_create(FILE *outstream, int msgfil, int pivotmodel, int updateli
   newLU->luparm[LUSOL_IP_KEEPLU]           = TRUE;
   newLU->luparm[LUSOL_IP_UPDATELIMIT]      = updatelimit;
 
-  /* init_BLAS(); */
+  init_BLAS();
 
   return( newLU );
 }
@@ -618,10 +628,8 @@ void LUSOL_free(LUSOLrec *LUSOL)
     LUSOL_matfree(&(LUSOL->L0));
   if(LUSOL->U != NULL)
     LUSOL_matfree(&(LUSOL->U));
-/*
   if(!is_nativeBLAS())
     unload_BLAS();
-*/
   LUSOL_FREE(LUSOL);
 }
 
